pub fn report_parser_error(source: &str, filename: &str, error: &ParserError)Expand description
Pretty-print a parser error with source context using ariadne
pub fn report_parser_error(source: &str, filename: &str, error: &ParserError)Pretty-print a parser error with source context using ariadne